@@ -1,4 +1,4 @@
-from typing import List, Tuple, OrderedDict
+from typing import List, Tuple
 from pymoo.model.problem import Problem
 from pymoo.algorithms.nsga2 import NSGA2
 from pymoo.factory import (
@@ -19,7 +19,7 @@ class MyProblem(Problem):
     def __init__(
         self,
         fitness_evaluator: FitnessEvaluator,
-        free_parameters_range: OrderedDict[str, Tuple[int, int]],
+        free_parameters_range,  # : OrderedDict[str, Tuple[int, int]],
         metrics: List[Tuple[str, str]],
     ):
         self.evaluator: FitnessEvaluator = fitness_evaluator
@@ -52,7 +52,7 @@ class MyProblem(Problem):
 
 def optimize(
     evaluator: FitnessEvaluator,
-    free_parameters_range: OrderedDict[str, Tuple[int, int]],
+    free_parameters_range,  # : OrderedDict[str, Tuple[int, int]],
     metrics,
     execution_time: str,
 ) -> np.ndarray:
